# Simple FTP server
## Usage
1. Configure firewall and ports forwarding (If you are behind NAT and OpenWRT is installed on your router, look at "./openwrt_firewall" and add it to the end of "/etc/config/firewall" on your router)
2. Go to your directory that you want to share and run
`./ftp_server.py`
